@@ -6,9 +6,9 @@ from typing import (
     Dict,
     Iterable,
     List,
-    Literal,
     NamedTuple,
     Optional,
+    Set,
     Tuple,
     Union,
     overload,
@@ -16,6 +16,7 @@ from typing import (
 
 from django.utils.encoding import force_str
 from django.utils.translation import get_language, override
+from typing_extensions import Literal
 
 from django_countries.conf import settings
 
@@ -364,9 +365,10 @@ class Countries(CountriesBase):
     def by_name(
         self,
         country: str,
+        *,
+        regex: Literal[False] = False,
         language: str = "en",
         insensitive: bool = True,
-        regex: Literal[False] = False,
     ) -> str:
         ...
 
@@ -374,19 +376,21 @@ class Countries(CountriesBase):
     def by_name(
         self,
         country: str,
+        *,
+        regex: Literal[True],
         language: str = "en",
         insensitive: bool = True,
-        regex: Literal[True] = False,
-    ) -> set[str]:
+    ) -> Set[str]:
         ...
 
     def by_name(
         self,
         country: str,
+        *,
+        regex: bool = False,
         language: str = "en",
         insensitive: bool = True,
-        regex: bool = False,
-    ) -> Union[str, set[str]]:
+    ) -> Union[str, Set[str]]:
         """
         Fetch a country's ISO3166-1 two letter country code from its name.
 
